@@ -185,18 +185,9 @@ sub _initialize_cipher($$)
 #                $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] );
             $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
             my $encrypt_rc4_key;
-            if ($_method eq 'rc4-md5' )
-            {
                 my $md = Digest::MD5->new();
                 $md->add($_key . $_iv);
                 $encrypt_rc4_key = $md->digest();
-            }
-            elsif($_method eq 'rc4-sha' )
-                {
-                       my $sha = Digest::SHA->new();
-                       $sha->add($_key . $_iv);
-                       $encrypt_rc4_key = substr($sha->digest(),0,16);
-                }
                 $_encryptor = Crypt::RC4::XS->new($encrypt_rc4_key);
         }       
         elsif($_method eq 'rabbit')
