@@ -25,7 +25,7 @@ package Net::Shadowsocks::Client;
        }
     }
     use Digest::MD5;
-    use Digest::SHA;
+    #use Digest::SHA;
     use IO::Socket::Socks qw(:constants);
     use Net::Shadowsocks;
     use Net::Shadowsocks qw( _get_algorithm _get_mode _get_iv_size _EVP_BytesToKey _initialize_cipher);
