@@ -26,7 +26,7 @@
        }
     }
     use Digest::MD5;
-    use Digest::SHA;
+    #use Digest::SHA;
     use Net::Shadowsocks;
     use Net::Shadowsocks qw(_get_algorithm _get_mode _get_key_size _EVP_BytesToKey _initialize_cipher);
     use Socket qw(IPPROTO_TCP TCP_FASTOPEN SOL_SOCKET SO_REUSEPORT SO_REUSEADDR);
